==> 1.7.2.zip: harbour-sailotp/translations/harbour-sailotp-it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/pages/About.qml" line="75"/>
        <source>A Simple Sailfish OTP Generator
(RFC 6238/4226 compatible)</source>
        <translation>Un semplice generatore di OTP per Sailfish
(compatibile con RFC 6238/4226)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="84"/>
        <source>Copyright: Stefan Brand
License: BSD (3-clause)</source>
        <translation>Copyright: Stefan Brand
Licenza: BSD (3-clause)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="110"/>
        <source>SailOTP uses the following third party libs:</source>
        <translation>SailOTP utilizza le seguenti librerie di terzi:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Contributors:</source>
        <translation>Collaboratori:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Support</source>
        <translation>Supporto</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="132"/>
        <source>Translators:</source>
        <translation>Traduttori:</translation>
    </message>
</context>
<context>
    <name>AddOTP</name>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="69"/>
        <source>Show QR-Code</source>
        <translation>Mostra Codice QR</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="72"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>Impossibile creare il codice QR da impostizioni incomplete!</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="86"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="86"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="91"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="93"/>
        <source>Time-based (TOTP)</source>
        <translation>Basato sul tempo (TOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="94"/>
        <source>Counter-based (HOTP)</source>
        <translation>Basato su contatore (HOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="95"/>
        <source>Steam Guard</source>
        <translation>Steam Guard</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="101"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="102"/>
        <source>Title for the OTP</source>
        <translation>Titolo per la OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="114"/>
        <source>Secret (at least 16 characters)</source>
        <translation>Segreto (almeno 16 caratteri)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="116"/>
        <source>Secret OTP Key</source>
        <translation>Chiave OTP segreta</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="128"/>
        <source>Length</source>
        <translation>Lunghezza</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="130"/>
        <source>Length of the Token</source>
        <translation>Lunghezza del Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="142"/>
        <location filename="../qml/pages/AddOTP.qml" line="144"/>
        <source>Time Derivation (Seconds)</source>
        <translation>Derivazione Temporale (Secondi)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="156"/>
        <source>Next Counter Value</source>
        <translation>Valore Prossimo Contatore</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="158"/>
        <source>Next Value of the Counter</source>
        <translation>Prossimo Valore del Contatore</translation>
    </message>
</context>
<context>
    <name>ExportPage</name>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="63"/>
        <source>File already exists, choose &quot;Overwrite existing&quot; to overwrite it.</source>
        <translation>Il file esiste già, scegli &quot;Sovrascrivi esistente&quot; per sovrascriverlo.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="72"/>
        <source>Given file does not exist!</source>
        <translation>Il file passato non esiste!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="114"/>
        <source>Filename</source>
        <translation>Nome file</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to import</source>
        <translation>File da importare</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to export</source>
        <translation>File da esportare</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="128"/>
        <source>Overwrite existing</source>
        <translation>Sovrascrivi esistente</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="134"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="135"/>
        <source>Password for the file</source>
        <translation>Password per il file</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords don&apos;t match!</source>
        <translation>Le password non corrispondono!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords match!</source>
        <translation>Le password corrispondono!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="149"/>
        <source>Repeated Password for the file</source>
        <translation>Password Ripetuta per il file</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="173"/>
        <source>Here you can Import Tokens from a file. Put in the file location and the password you used on export. Pull left to start the import.</source>
        <translation>Da qua puoi Importare i Token da un file. Inserisci la posizione del file e la password usata nell&apos;esportazione. Scorri a sinistra per iniziare l&apos;importazione.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>Here you can export Tokens to a file. The exported file will be encrypted with AES-256-CBC and Base64 encoded. Choose a strong password, the file will contain the secrets used to generate the Tokens for your accounts. Pull left to start the export.</source>
        <translation>Da qua puoi Esportare i Token su un file. Il file esportato sarà criptato con AES-256-CBC e codificato Base64. Scegli una password forte, il file conterrà i segreti usati per generare i Token per i tuoi account. Scorri a sinistra per iniziare l&apos;esportazione.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>To view the content of the export file outside of SailOTP use the following openssl command:</source>
        <translation>Per vedere il contenuto del file esportato al di fuori di SailORP usa il seguente comando openssl:</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="211"/>
        <source>Error writing to file </source>
        <translation>Errore in scrittura del file </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="213"/>
        <source>Token Database exported to </source>
        <translation>Database dei Toen esportato su </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="216"/>
        <source>Could not encrypt tokens. Error: </source>
        <translation>Impossibile criptare i token. Errore: </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="219"/>
        <source>Could not read tokens from Database</source>
        <translation>Impossibile leggere i token dal Database</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="230"/>
        <source>Tokens imported from </source>
        <translation>Token importati da </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="235"/>
        <source>Unable to decrypt file, did you use the right password?</source>
        <translation>Non ho potuto decrittare il file, hai scritto la password correttamente?</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="238"/>
        <source>Could not read from file </source>
        <translation>Impossibile leggere dal file </translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../qml/pages/MainView.qml" line="96"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="100"/>
        <source>Settings</source>
        <translation>Imopstazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="105"/>
        <source>Export / Import</source>
        <translation>Esporta / Importa</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="109"/>
        <source>Add Token</source>
        <translation>Aggiungi Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="139"/>
        <source>Nothing here</source>
        <translation>Qua non c&apos;è nulla</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="140"/>
        <source>Pull down to add a OTP</source>
        <translation>Trascina giù per aggiungere una OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="151"/>
        <source>Deleting</source>
        <translation>Cancellazione</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="167"/>
        <source>Token for </source>
        <translation>Token per </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="167"/>
        <source> copied to clipboard</source>
        <translation> copiato negli appunti</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="235"/>
        <source>Move up</source>
        <translation>Sposta su</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="240"/>
        <source>Move down</source>
        <translation>Sposta giù</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="245"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="251"/>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>QRPage</name>
    <message>
        <location filename="../qml/pages/QRPage.qml" line="74"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>Impossibile creare il codice QR da impostizioni incomplete!</translation>
    </message>
</context>
<context>
    <name>ScanOTP</name>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="54"/>
        <source>Can&apos;t access temporary directory</source>
        <translation>Impossibile accedere alla cartella temporanea</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="64"/>
        <source>Add manually</source>
        <translation>Aggiungi manualmente</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scan Code</source>
        <translation>Scansiona Codice</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scanning...</source>
        <translation>Scansione...</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="101"/>
        <source>No valid Token data found.</source>
        <translation>Non sono stati trovati dati di Token validi.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="142"/>
        <source>Tap the picture to start / stop scanning. Pull down to add Token manually.</source>
        <translation>Tocca l&apos;immagine per iniziare / fermare la scansione. Trascina giù per aggiungere manualmente un Token.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="50"/>
        <source>Settings</source>
        <translation>Imopstazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="52"/>
        <source>Behaviour</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Show Token as QRCode on Tap</source>
        <translation>Mostra il Token come Codice QR al Tocco</translation>
    </message>
</context>
</TS>

==> 1.9.2.zip: harbour-sailotp/translations/harbour-sailotp-it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/pages/About.qml" line="70"/>
        <source>A simple Sailfish OTP generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="78"/>
        <source>(RFC 6238/4226 compatible)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="87"/>
        <source>Online Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="94"/>
        <source>Source Code &amp; Issue Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="111"/>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="120"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="120"/>
        <source>BSD (3-clause)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="139"/>
        <source>SteamGuard support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="146"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="240"/>
        <source>SailOTP uses the following third party libs:</source>
        <translation>SailOTP utilizza le seguenti librerie di terzi:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="133"/>
        <source>Contributors:</source>
        <translation>Collaboratori:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="162"/>
        <source>Translators:</source>
        <translation>Traduttori:</translation>
    </message>
</context>
<context>
    <name>AddOTP</name>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="69"/>
        <source>Show QR-Code</source>
        <translation>Mostra Codice QR</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="72"/>
        <location filename="../qml/pages/AddOTP.qml" line="85"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>Impossibile creare il codice QR da impostizioni incomplete!</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="103"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="105"/>
        <source>Time-based (TOTP)</source>
        <translation>Basato sul tempo (TOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="106"/>
        <source>Counter-based (HOTP)</source>
        <translation>Basato su contatore (HOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="107"/>
        <source>Steam Guard</source>
        <translation>Steam Guard</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="113"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="114"/>
        <source>Title for the OTP</source>
        <translation>Titolo per la OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="126"/>
        <source>Secret (at least 16 characters)</source>
        <translation>Segreto (almeno 16 caratteri</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="128"/>
        <source>Secret OTP Key</source>
        <translation>Chiave OTP segreta</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="142"/>
        <source>Length</source>
        <translation>Lunghezza</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="144"/>
        <source>Length of the Token</source>
        <translation>Lunghezza del Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="156"/>
        <location filename="../qml/pages/AddOTP.qml" line="158"/>
        <source>Time Derivation (Seconds)</source>
        <translation>Derivazione Temporale (Secondi)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="170"/>
        <source>Next Counter Value</source>
        <translation>Valore Prossimo Contatore</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="172"/>
        <source>Next Value of the Counter</source>
        <translation>Prossimo Valore del Contatore</translation>
    </message>
</context>
<context>
    <name>ExportPage</name>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="63"/>
        <source>File already exists, choose &quot;Overwrite existing&quot; to overwrite it.</source>
        <translation>Il file esiste già, scegli &quot;Sovrascrivi esistente&quot; per sovrascriverlo.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="72"/>
        <source>Given file does not exist!</source>
        <translation>Il file passato non esiste!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="114"/>
        <source>Filename</source>
        <translation>Nome file</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to import</source>
        <translation>File da importare</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to export</source>
        <translation>File da esportare</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="128"/>
        <source>Overwrite existing</source>
        <translation>Sovrascrivi esistente</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="134"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="135"/>
        <source>Password for the file</source>
        <translation>Password per il file</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords don&apos;t match!</source>
        <translation>Le password non corrispondono!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords match!</source>
        <translation>Le password corrispondono!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="149"/>
        <source>Repeated Password for the file</source>
        <translation>Password Ripetuta per il file</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="173"/>
        <source>Here you can Import Tokens from a file. Put in the file location and the password you used on export. Pull left to start the import.</source>
        <translation>Da qua puoi Importare i Token da un file. Inserisci la posizione del file e la password usata nell&apos;esportazione. Scorri a sinistra per iniziare l&apos;importazione.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>Here you can export Tokens to a file. The exported file will be encrypted with AES-256-CBC and Base64 encoded. Choose a strong password, the file will contain the secrets used to generate the Tokens for your accounts. Pull left to start the export.</source>
        <translation>Da qua puoi Esportare i Token su un file. Il file esportato sarà criptato con AES-256-CBC e codificato Base64. Scegli una password forte, il file conterrà i segreti usati per generare i Token per i tuoi account. Scorri a sinistra per iniziare l&apos;esportazione.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>To view the content of the export file outside of SailOTP use the following openssl command:</source>
        <translation>Per vedere il contenuto del file esportato al di fuori di SailORP usa il seguente comando openssl:</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="211"/>
        <source>Error writing to file </source>
        <translation>Errore in scrittura del file </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="213"/>
        <source>Token Database exported to </source>
        <translation>Database dei Toen esportato su </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="216"/>
        <source>Could not encrypt tokens. Error: </source>
        <translation>Impossibile criptare i token. Errore: </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="219"/>
        <source>Could not read tokens from Database</source>
        <translation>Impossibile leggere i token dal Database</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="230"/>
        <source>Tokens imported from </source>
        <translation>Token importati da </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="235"/>
        <source>Unable to decrypt file, did you use the right password?</source>
        <translation>Non ho potuto decrittare il file, hai scritto la password correttamente?</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="238"/>
        <source>Could not read from file </source>
        <translation>Impossibile leggere dal file </translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../qml/pages/MainView.qml" line="109"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="113"/>
        <source>Settings</source>
        <translation>Imopstazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="118"/>
        <source>Export / Import</source>
        <translation>Esporta / Importa</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="122"/>
        <source>Add Token</source>
        <translation>Aggiungi Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="136"/>
        <source>Nothing here</source>
        <translation>Qua non c&amp;apos;è nulla</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="137"/>
        <source>Pull down to add a OTP</source>
        <translation>Trascina giù per aggiungere una OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="178"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="198"/>
        <source>Deleting</source>
        <translation>Cancellazione</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="219"/>
        <location filename="../qml/pages/MainView.qml" line="293"/>
        <source>Token for </source>
        <translation>Token per </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="219"/>
        <location filename="../qml/pages/MainView.qml" line="293"/>
        <source> copied to clipboard</source>
        <translation> copiato negli appunti</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="289"/>
        <source>Copy to Clipboard</source>
        <translation>Copia negli appunti</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="297"/>
        <source>Show Token as QR-Code</source>
        <translation>Mostra Codice QR</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="302"/>
        <source>Move up</source>
        <translation>&gt;Sposta su</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="307"/>
        <source>Move down</source>
        <translation>Sposta giù</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="312"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="318"/>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>QRPage</name>
    <message>
        <location filename="../qml/pages/QRPage.qml" line="74"/>
        <source>Can&apos;t create QR-Code from an empty String</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Impossibile creare il codice QR da una stringa vuota</translation>
    </message>
</context>
<context>
    <name>ScanOTP</name>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="54"/>
        <source>Can&apos;t access temporary directory</source>
        <translation>Impossibile accedere alla cartella temporanea</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="64"/>
        <source>Add manually</source>
        <translation>Aggiungi manualmente</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scan Code</source>
        <translation>Scansiona Codice</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scanning...</source>
        <translation>Scansione...</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="96"/>
        <source>No valid Token data found.</source>
        <translation>Non sono stati trovati dati di Token validi.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="137"/>
        <source>Tap the picture to start / stop scanning. Pull down to add Token manually.</source>
        <translation>Tocca l&apos;immagine per iniziare / fermare la scansione. Trascina giù per aggiungere manualmente un Token.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="50"/>
        <source>Settings</source>
        <translation>Imopstazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="52"/>
        <source>Behaviour</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Show Token as QR on Tap</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Mostra Token come QR alla pressione</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="68"/>
        <source>Hide Tokens and Reveal on Tap</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Nascondi token e rivela alla spina</translation>
    </message>
</context>
</TS>
